@@ -23,6 +23,7 @@
 #include <hildon/hildon-seekbar.h>
 #include <hildon/hildon-file-chooser-dialog.h>
 #include <hildon/hildon-banner.h>
+#include <hildon/hildon-pannable-area.h>
 
 #define bool char
 #define true 1
@@ -163,6 +164,8 @@ static void _app_setup_window (GtkWidget * w, Application *app) {
         GTK_SIGNAL_FUNC (cb_view_area_expose), app);
     g_signal_connect (G_OBJECT (w), "button-press-event",
         GTK_SIGNAL_FUNC (cb_view_area_button_press), app);
+    g_signal_connect (G_OBJECT (w), "key-press-event",
+        GTK_SIGNAL_FUNC (cb_view_area_key_press), app);
 }
 
 void app_full_screen (Application *app) {
@@ -514,7 +517,7 @@ void cbPluginRemoved (GtkSocket *socket, Application *app) {
 int main (int argc, char* argv[]) {
     HildonProgram *program;
     HildonWindow *main_window;
-    GtkScrolledWindow *scroll_window;
+    GtkWidget *scroll_window;
     PangoContext *pango_cxt;
     PangoFontDescription *pfd;
     Application *app;
@@ -543,6 +546,10 @@ int main (int argc, char* argv[]) {
         return 1;
     }
     gtk_init (&argc, &argv);
+    gtk_rc_parse_string ("style \"kmplayer-touchlist\" = \"fremantle-touchlist\" {\n"
+            "  GtkTreeView::row-height = 50\n"
+            "} widget_class \"*.<GtkPaned>.<HildonPannableArea>.<GtkTreeView>\" "
+            "style \"kmplayer-touchlist\"");
 
     /* Create the hildon application and setup the title */
     program = HILDON_PROGRAM (hildon_program_get_instance());
@@ -561,13 +568,14 @@ int main (int argc, char* argv[]) {
     /* Add example label to appview */
     app->hsplit_view = GTK_PANED (gtk_hpaned_new ());
     scroll_window = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (0L, 0l));
-    gtk_scrolled_window_set_policy (scroll_window,
-            GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    scroll_window = hildon_pannable_area_new ();
+    g_object_set (G_OBJECT (scroll_window),
+            "mov-mode", HILDON_MOVEMENT_MODE_BOTH, 0);
     app->playlist_view = createTreeView (app);
     gtk_container_add (GTK_CONTAINER (scroll_window), app->playlist_view);
     app->vsplit_view = GTK_PANED (gtk_vpaned_new ());
     app->isplit_view = gtk_vbox_new (false, 0);
-    gtk_paned_pack1 (app->hsplit_view, GTK_WIDGET (scroll_window), true, false);
+    gtk_paned_pack1 (app->hsplit_view, scroll_window, true, false);
     gtk_paned_pack2 (app->hsplit_view, GTK_WIDGET (app->vsplit_view), true, false);
     app->view_base = gtk_alignment_new (0, 0, 1, 1);
     app->view_area = gtk_fixed_new ();
