@@ -72,6 +72,15 @@ void SourceDocument::message (MessageType msg, void *data) {
                 data ? (const char *) *((String *) data) : "", false);
         return;
 
+    case MsgAccessKey:
+        for (Connection *c = m_KeyListeners.first(); c; c = m_KeyListeners.next ())
+            if (c->payload && c->connecter) {
+                KeyLoad *load = (KeyLoad *) c->payload;
+                if (load->key == (int) (long) data)
+                    post (new Posting (this, c->connecter, MsgAccessKey));
+            }
+        return;
+
     default:
         break;
     }
@@ -88,10 +97,19 @@ void *SourceDocument::role (RoleType msg, void *data) {
         return VIEWAREA(m_control->m_app)->getSurface ((Mrl *) data);
 
     case RoleReceivers:
-        if (MsgSurfaceUpdate == (MessageType) (long) data)
+        switch ((MessageType) (long) data) {
+
+        case MsgAccessKey:
+            return &m_KeyListeners;
+
+        case MsgSurfaceUpdate:
             return VIEWAREA(m_control->m_app)->updaters ();
 
+        default:
+            break;
+        }
         // fall through
+
     default:
         break;
     }
@@ -133,8 +151,12 @@ void Control::init () {
     gst->setAudioDriver ("pulse");
     gst->setVideoDriver ("xv");
     media_server = gst;
-    if (glob ("/usr/bin/mplayer", 0, NULL, &globbuf) != GLOB_NOMATCH)
-        mplayer = new MPlayer (this, "mplayer");
+    if (glob ("/usr/bin/mplayer", 0, NULL, &globbuf) != GLOB_NOMATCH) {
+        MPlayer *mp = new MPlayer (this, "mplayer");
+        mp->setVideoDriver ("xv:ck-method=auto");
+        //mp->setAudioDriver ("pulse");
+        mplayer = mp;
+    }
     globfree (&globbuf);
 #ifdef __ARMEL__
     npp = new NpPlayer (this);
@@ -154,9 +176,9 @@ void Control::init () {
     addTree (m_app, 0L, //gdk_pixbuf_new_from_xpm_data((const char**)www_xpm));
             gdk_pixbuf_scale_simple (
                     gtk_icon_theme_load_icon (icon_theme,
-                        "general_web", 26,
+                        "general_web", 36,
                         (GtkIconLookupFlags)0, 0L),
-                    26, 26, GDK_INTERP_BILINEAR));
+                    36, 36, GDK_INTERP_BILINEAR));
 
     const String home = getenv ("HOME");
     if (!home.isEmpty ()) {
@@ -181,7 +203,7 @@ void Control::init () {
 
     m_app->playlists_tree_id = addTree (m_app, pldoc,
             gtk_icon_theme_load_icon(icon_theme,
-                "kmplayer-fav", 26, (GtkIconLookupFlags)0, 0L));
+                "kmplayer-fav", 36, (GtkIconLookupFlags)0, 0L));
     GConfClient *client = (GConfClient *) *m_config;
     GSList *plists = gconf_client_all_entries (client, GCONF_KEY_LISTS, NULL );
     for (GSList *elm = plists; elm; elm = elm->next) {
@@ -195,7 +217,7 @@ void Control::init () {
             expl->path = str;
             addTree (m_app, expl,
                     gtk_icon_theme_load_icon(icon_theme,
-                      "filemanager_playlist", 26, (GtkIconLookupFlags)0, 0L));
+                      "filemanager_playlist", 36, (GtkIconLookupFlags)0, 0L));
         }
         gconf_entry_free (entry);
     }
@@ -216,7 +238,7 @@ void Control::init () {
     rcdoc->path = tmp;
     m_app->recents_tree_id = addTree (m_app, rcdoc,
             gtk_icon_theme_load_icon(icon_theme,
-                "general_clock", 26, (GtkIconLookupFlags)0, 0L));
+                "general_clock", 36, (GtkIconLookupFlags)0, 0L));
 
     String sf = m_config->readEntry (GCONF_KEY_SAVE_FOLDER, String());
     if (!sf.isEmpty ())
@@ -310,7 +332,6 @@ void Control::play () {
 }
 
 void Control::stop (bool keep_fullscreen) {
-    setLoading (100); // no pogress bar
     back_request = 0L;
     if (playlist_data->document &&
             playlist_data->document->state > Node::state_init) {
@@ -361,6 +382,7 @@ void Control::stop (bool keep_fullscreen) {
         }
     }
     m_process->quit ();
+    setLoading (100); // no pogress bar
 
     VIEWAREA(m_app)->scheduleRepaint (IRect (0, 0,
                     VIEWAREA(m_app)->width (), VIEWAREA(m_app)->height ()));
@@ -471,14 +493,18 @@ bool Control::applyBackRequest() {
     return true;
 }
 
-static String processForMimetype (Config *config, const String & mime) {
-    String pname = config->readEntry (String (GCONF_KEY_MIME) + mime, "");
+static String processForMimetype (Control *ctr, const String & mime)
+{
+    String pname = ctr->m_config->readEntry(String (GCONF_KEY_MIME) + mime, "");
+#ifdef __ARMEL__
     if (pname.isEmpty ()) {
         // hardcoded defaults FIXME
-        if (mime == "application/x-shockwave-flash" ||
-                mime == "application/futuresplash")
+        if (NpPlayer::isFlashMimeType (mime))
             pname = "npp";
+        if (mime == "video/x-flv" || mime == "video/flv")
+            pname = ctr->mplayer ? "mplayer" : "npp";
     }
+#endif
     return pname;
 }
 
@@ -548,7 +574,7 @@ bool Control::setProcess (Mrl *mrl) {
             pname = p;
     }
     if (pname.isEmpty () && !mrl->mimetype.isEmpty ())
-        pname = processForMimetype (m_config, mrl->mimetype);
+        pname = processForMimetype (this, mrl->mimetype);
     if (pname.isEmpty ())
         pname = m_config->readEntry (GCONF_KEY_PLAYER, "osso-media-server");
     if (!m_process || pname != m_process->name ()) {
